InputImage class

Image format that ML Kit takes to process the image.

Constructors

InputImage.fromBytes({required Uint8List bytes, required InputImageData inputImageData})
Creates an instance of InputImage using bytes.
factory
InputImage.fromFile(File file)
Creates an instance of InputImage by passing a file.
factory
InputImage.fromFilePath(String path)
Creates an instance of InputImage from path of image stored in device.
factory

Properties

bytes → Uint8List?
The bytes of the image.
final
filePath → String?
The file path to the image.
final
hashCode → int
The hash code for this object.
no setterinherited
inputImageData → InputImageData?
The image data when creating an image of type = InputImageType.bytes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InputImageType
The type of image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a json representation of an instance of InputImage.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited