InputImageData class

Data of image required when creating image from bytes.

Constructors

InputImageData({required Size size, required InputImageRotation imageRotation, required InputImageFormat inputImageFormat, required List<InputImagePlaneMetadata>? planeData})
Constructor to create an instance of InputImageData.

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageRotation → InputImageRotation
Image rotation degree.
final
inputImageFormat → InputImageFormat
Format of the input image.
final
planeData → List<InputImagePlaneMetadata>?
The plane attributes to create the image buffer on iOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
Size of image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a json representation of an instance of InputImageData.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited