InputImageFormat enum

To indicate the format of image while creating input image from bytes

Inheritance
Available extensions

Values

nv21 → const InputImageFormat
yv12 → const InputImageFormat
yuv_420_888 → const InputImageFormat
yuv420 → const InputImageFormat
bgra8888 → const InputImageFormat

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int

Available on InputImageFormat, provided by the InputImageFormatValue extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<InputImageFormat>
A constant List of the values in this enum, in order of their declaration.