InputImagePlaneMetadata class

Plane attributes to create the image buffer on iOS.

When using iOS, height, and width throw AssertionError if null.

Constructors

InputImagePlaneMetadata({required int bytesPerRow, int? height, int? width})
Constructor to create an instance of InputImagePlaneMetadata.

Properties

bytesPerRow → int
The row stride for this color plane, in bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
Height of the pixel buffer on iOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
Width of the pixel buffer on iOS.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a json representation of an instance of InputImagePlaneMetadata.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited