ModelManager class

A class to manage remote models.

Constructors

ModelManager({required MethodChannel channel, required String method})
Constructor to create an instance of ModelManager.

Properties

channel → MethodChannel
The channel used to manage the remote model.
final
hashCode → int
The hash code for this object.
no setterinherited
method → String
The method name to be called.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteModel(String model) → Future<bool>
Deletes a model. Returns true if model is deleted successfully or model is not present.
downloadModel(String model, {bool isWifiRequired = true}) → Future<bool>
Downloads a model. Returns true if model downloads successfully or model is already downloaded. On failing to download it throws an error.
isModelDownloaded(String model) → Future<bool>
Checks whether a model is downloaded or not.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited